[Libreoffice-commits] core.git: 25 commits - basebmp/test canvas/source comphelper/source dtrans/source editeng/source embeddedobj/source embeddedobj/test extensions/source forms/source framework/source include/comphelper include/o3tl include/unotools odk/examples package/source sal/workben sc/source sd/source sfx2/source solenv/gbuild starmath/inc starmath/source svtools/source svx/source sw/source testtools/source ucb/source udkapi/com vcl/source winaccessibility/source xmloff/source

Thomas Arnhold thomas at arnhold.org
Sat Mar 29 11:17:06 PDT 2014


 basebmp/test/polytest.cxx                                                     |    2 -
 canvas/source/vcl/canvashelper_texturefill.cxx                                |    4 +-
 comphelper/source/container/container.cxx                                     |    2 -
 comphelper/source/container/containermultiplexer.cxx                          |    2 -
 comphelper/source/container/embeddedobjectcontainer.cxx                       |   16 +++++-----
 comphelper/source/container/enumerablemap.cxx                                 |    2 -
 comphelper/source/misc/evtmethodhelper.cxx                                    |    8 -----
 comphelper/source/misc/officeresourcebundle.cxx                               |    2 -
 comphelper/source/misc/proxyaggregation.cxx                                   |    2 -
 comphelper/source/property/propertycontainerhelper.cxx                        |    2 -
 comphelper/source/streaming/seqstream.cxx                                     |    2 -
 dtrans/source/win32/clipb/MtaOleClipb.cxx                                     |    2 -
 editeng/source/uno/unofored.cxx                                               |    6 +--
 embeddedobj/source/inc/commonembobj.hxx                                       |    2 -
 embeddedobj/test/Container1/EmbedContApp.java                                 |    4 +-
 extensions/source/bibliography/loadlisteneradapter.cxx                        |    2 -
 forms/source/component/ImageControl.cxx                                       |    2 -
 forms/source/inc/FormComponent.hxx                                            |    2 -
 framework/source/services/frame.cxx                                           |    2 -
 include/comphelper/types.hxx                                                  |    2 -
 include/o3tl/sorted_vector.hxx                                                |    2 -
 include/unotools/syslocaleoptions.hxx                                         |    2 -
 odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/FunctionHelper.java |    2 -
 odk/examples/java/EmbedDocument/Container1/EmbedContApp.java                  |    2 -
 package/source/zippackage/ZipPackage.cxx                                      |    2 -
 sal/workben/clipboardwben/testpaste/cbptest.cxx                               |    2 -
 sc/source/ui/unoobj/scdetect.cxx                                              |    4 +-
 sd/source/ui/slideshow/slideshowviewimpl.cxx                                  |    2 -
 sd/source/ui/unoidl/sddetect.cxx                                              |    4 +-
 sfx2/source/doc/objstor.cxx                                                   |    4 +-
 sfx2/source/view/ipclient.cxx                                                 |    2 -
 solenv/gbuild/platform/com_MSC_defs.mk                                        |    2 -
 starmath/inc/caret.hxx                                                        |    4 +-
 starmath/inc/cursor.hxx                                                       |    8 ++---
 starmath/inc/document.hxx                                                     |    2 -
 starmath/inc/node.hxx                                                         |    6 +--
 starmath/inc/toolbox.hxx                                                      |    2 -
 starmath/inc/visitors.hxx                                                     |    4 +-
 starmath/source/accessibility.cxx                                             |    8 ++---
 starmath/source/cursor.cxx                                                    |    2 -
 starmath/source/node.cxx                                                      |    2 -
 starmath/source/smdetect.cxx                                                  |    4 +-
 starmath/source/view.cxx                                                      |    2 -
 svtools/source/misc/embedtransfer.cxx                                         |    2 -
 svx/source/sdr/contact/viewcontactofe3dscene.cxx                              |    2 -
 svx/source/table/tablecontroller.cxx                                          |    2 -
 sw/source/core/doc/doctxm.cxx                                                 |    2 -
 sw/source/core/layout/wsfrm.cxx                                               |    2 -
 sw/source/core/ole/ndole.cxx                                                  |    2 -
 sw/source/core/text/pormulti.cxx                                              |    2 -
 sw/source/core/uibase/wrtsh/wrtsh1.cxx                                        |    2 -
 sw/source/ui/uno/swdetect.cxx                                                 |    4 +-
 testtools/source/bridgetest/idl/bridgetest.idl                                |    2 -
 ucb/source/ucp/file/filglob.cxx                                               |    2 -
 udkapi/com/sun/star/reflection/XIdlClass.idl                                  |    2 -
 udkapi/com/sun/star/uno/XReference.idl                                        |    2 -
 vcl/source/gdi/outdev2.cxx                                                    |    2 -
 vcl/source/window/window.cxx                                                  |    4 +-
 winaccessibility/source/UAccCOMIDL/ia2_api_all.idl                            |    4 +-
 xmloff/source/draw/shapeexport.cxx                                            |    2 -
 xmloff/source/text/XMLTextFrameContext.cxx                                    |    2 -
 61 files changed, 89 insertions(+), 95 deletions(-)

New commits:
commit 6f892ed9fc3b836e0d23681a16425ebd60aa61f8
Author: Thomas Arnhold <thomas at arnhold.org>
Date:   Sat Mar 29 19:01:06 2014 +0100

    typo: overrride -> override
    
    All detected by SpellCode
    
    https://code.google.com/p/spellcode/

diff --git a/extensions/source/bibliography/loadlisteneradapter.cxx b/extensions/source/bibliography/loadlisteneradapter.cxx
index e74c24e..27b278c 100644
--- a/extensions/source/bibliography/loadlisteneradapter.cxx
+++ b/extensions/source/bibliography/loadlisteneradapter.cxx
@@ -46,7 +46,7 @@ namespace bib
 
     void OComponentListener::_disposing( const EventObject& /*_rSource*/ ) throw( RuntimeException)
     {
-        // nothing to do here, overrride if you're interested in
+        // nothing to do here, override if you're interested in
     }
 
 
diff --git a/starmath/source/node.cxx b/starmath/source/node.cxx
index 9a6ea0c..a76e7c5 100644
--- a/starmath/source/node.cxx
+++ b/starmath/source/node.cxx
@@ -1077,7 +1077,7 @@ void SmRootNode::Arrange(const OutputDevice &rDev, const SmFormat &rFormat)
     pRootSym->Arrange(rDev, rFormat);
 
     Point  aPos = pRootSym->AlignTo(*pBody, RP_LEFT, RHA_CENTER, RVA_BASELINE);
-    //! overrride calculated vertical position
+    //! override calculated vertical position
     aPos.Y()  = pRootSym->GetTop() + pBody->GetBottom() - pRootSym->GetBottom();
     aPos.Y() -= nVerOffset;
     pRootSym->MoveTo(aPos);
commit 680139fe7d51cf3c3ada1ce12fe507c298f02b67
Author: Thomas Arnhold <thomas at arnhold.org>
Date:   Sat Mar 29 18:59:34 2014 +0100

    typo: opend -> opened

diff --git a/framework/source/services/frame.cxx b/framework/source/services/frame.cxx
index ad5aeda..ce6f4a4 100644
--- a/framework/source/services/frame.cxx
+++ b/framework/source/services/frame.cxx
@@ -2598,7 +2598,7 @@ void SAL_CALL Frame::windowDeactivated( const css::lang::EventObject& aEvent ) t
         {
             css::uno::Reference< css::awt::XWindow >  xParentWindow   = xParent->getContainerWindow()             ;
             Window*                                   pParentWindow   = VCLUnoHelper::GetWindow( xParentWindow    );
-            //#i70261#: dialogs opend from an OLE object will cause a deactivate on the frame of the OLE object
+            //#i70261#: dialogs opened from an OLE object will cause a deactivate on the frame of the OLE object
             // on Solaris/Linux at that time pFocusWindow is still NULL because the focus handling is different; right after
             // the deactivation the focus will be set into the dialog!
             // currently I see no case where a sub frame could get a deactivate with pFocusWindow being NULL permanently
diff --git a/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/FunctionHelper.java b/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/FunctionHelper.java
index 6060292..5bf3f2c 100644
--- a/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/FunctionHelper.java
+++ b/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/FunctionHelper.java
@@ -988,7 +988,7 @@ public class FunctionHelper
      *
      * @param   aParent parent window of this dialog
      * @param   bOpen   If it is set to true =>
-     *                  dialog is opend in "file open" mode -
+     *                  dialog is opened in "file open" mode -
      *                  otherwise in "file save" mode.
      */
     public static String askUserForFileURL(Component aParent,boolean bOpen)
diff --git a/sc/source/ui/unoobj/scdetect.cxx b/sc/source/ui/unoobj/scdetect.cxx
index 11f8444..877925b 100644
--- a/sc/source/ui/unoobj/scdetect.cxx
+++ b/sc/source/ui/unoobj/scdetect.cxx
@@ -557,7 +557,7 @@ OUString SAL_CALL ScFilterDetect::detect( uno::Sequence<beans::PropertyValue>& l
 
     if ( nIndexOfInputStream == -1 && xStream.is() )
     {
-        // if input stream wasn't part of the descriptor, now it should be, otherwise the content would be opend twice
+        // if input stream wasn't part of the descriptor, now it should be, otherwise the content would be opened twice
         lDescriptor.realloc( nPropertyCount + 1 );
         lDescriptor[nPropertyCount].Name = "InputStream";
         lDescriptor[nPropertyCount].Value <<= xStream;
@@ -566,7 +566,7 @@ OUString SAL_CALL ScFilterDetect::detect( uno::Sequence<beans::PropertyValue>& l
 
     if ( nIndexOfContent == -1 && xContent.is() )
     {
-        // if input stream wasn't part of the descriptor, now it should be, otherwise the content would be opend twice
+        // if input stream wasn't part of the descriptor, now it should be, otherwise the content would be opened twice
         lDescriptor.realloc( nPropertyCount + 1 );
         lDescriptor[nPropertyCount].Name = "UCBContent";
         lDescriptor[nPropertyCount].Value <<= xContent;
diff --git a/sd/source/ui/unoidl/sddetect.cxx b/sd/source/ui/unoidl/sddetect.cxx
index b1c12c1..fa3cdae 100644
--- a/sd/source/ui/unoidl/sddetect.cxx
+++ b/sd/source/ui/unoidl/sddetect.cxx
@@ -450,7 +450,7 @@ OUString SAL_CALL SdFilterDetect::detect( Sequence< beans::PropertyValue >& lDes
 
     if ( nIndexOfInputStream == -1 && xStream.is() )
     {
-        // if input stream wasn't part of the descriptor, now it should be, otherwise the content would be opend twice
+        // if input stream wasn't part of the descriptor, now it should be, otherwise the content would be opened twice
         lDescriptor.realloc( nPropertyCount + 1 );
         lDescriptor[nPropertyCount].Name = "InputStream";
         lDescriptor[nPropertyCount].Value <<= xStream;
@@ -459,7 +459,7 @@ OUString SAL_CALL SdFilterDetect::detect( Sequence< beans::PropertyValue >& lDes
 
     if ( nIndexOfContent == -1 && xContent.is() )
     {
-        // if input stream wasn't part of the descriptor, now it should be, otherwise the content would be opend twice
+        // if input stream wasn't part of the descriptor, now it should be, otherwise the content would be opened twice
         lDescriptor.realloc( nPropertyCount + 1 );
         lDescriptor[nPropertyCount].Name = "UCBContent";
         lDescriptor[nPropertyCount].Value <<= xContent;
diff --git a/starmath/source/smdetect.cxx b/starmath/source/smdetect.cxx
index c53b530..14e0a39 100644
--- a/starmath/source/smdetect.cxx
+++ b/starmath/source/smdetect.cxx
@@ -368,7 +368,7 @@ OUString SAL_CALL SmFilterDetect::detect( Sequence< PropertyValue >& lDescriptor
 
     if ( nIndexOfInputStream == -1 && xStream.is() )
     {
-        // if input stream wasn't part of the descriptor, now it should be, otherwise the content would be opend twice
+        // if input stream wasn't part of the descriptor, now it should be, otherwise the content would be opened twice
         lDescriptor.realloc( nPropertyCount + 1 );
         lDescriptor[nPropertyCount].Name = "InputStream";
         lDescriptor[nPropertyCount].Value <<= xStream;
@@ -377,7 +377,7 @@ OUString SAL_CALL SmFilterDetect::detect( Sequence< PropertyValue >& lDescriptor
 
     if ( nIndexOfContent == -1 && xContent.is() )
     {
-        // if input stream wasn't part of the descriptor, now it should be, otherwise the content would be opend twice
+        // if input stream wasn't part of the descriptor, now it should be, otherwise the content would be opened twice
         lDescriptor.realloc( nPropertyCount + 1 );
         lDescriptor[nPropertyCount].Name = "UCBContent";
         lDescriptor[nPropertyCount].Value <<= xContent;
diff --git a/sw/source/ui/uno/swdetect.cxx b/sw/source/ui/uno/swdetect.cxx
index b448e86..69b7d9e 100644
--- a/sw/source/ui/uno/swdetect.cxx
+++ b/sw/source/ui/uno/swdetect.cxx
@@ -349,7 +349,7 @@ OUString SAL_CALL SwFilterDetect::detect( Sequence< PropertyValue >& lDescriptor
 
     if ( nIndexOfInputStream == -1 && xStream.is() )
     {
-        // if input stream wasn't part of the descriptor, now it should be, otherwise the content would be opend twice
+        // if input stream wasn't part of the descriptor, now it should be, otherwise the content would be opened twice
         lDescriptor.realloc( nPropertyCount + 1 );
         lDescriptor[nPropertyCount].Name = "InputStream";
         lDescriptor[nPropertyCount].Value <<= xStream;
@@ -358,7 +358,7 @@ OUString SAL_CALL SwFilterDetect::detect( Sequence< PropertyValue >& lDescriptor
 
     if ( nIndexOfContent == -1 && xContent.is() )
     {
-        // if input stream wasn't part of the descriptor, now it should be, otherwise the content would be opend twice
+        // if input stream wasn't part of the descriptor, now it should be, otherwise the content would be opened twice
         lDescriptor.realloc( nPropertyCount + 1 );
         lDescriptor[nPropertyCount].Name = "UCBContent";
         lDescriptor[nPropertyCount].Value <<= xContent;
commit d6837aa330821dd7b10ea14536e4fb1d41aa9a37
Author: Thomas Arnhold <thomas at arnhold.org>
Date:   Sat Mar 29 18:57:43 2014 +0100

    typo: soultion -> solution

diff --git a/starmath/source/view.cxx b/starmath/source/view.cxx
index 0686320..29383a2 100644
--- a/starmath/source/view.cxx
+++ b/starmath/source/view.cxx
@@ -816,7 +816,7 @@ IMPL_LINK( SmCmdBoxWindow, InitialFocusTimerHdl, Timer *, EMPTYARG /*pTimer*/ )
     // We want to have the focus in the edit window once Math has been opened
     // to allow for immediate typing.
     // Problem: There is no proper way to do this
-    // Thus: this timer based soultion has been implemented (see GrabFocus below)
+    // Thus: this timer based solution has been implemented (see GrabFocus below)
 
     // Follow-up problem (#i114910): grabing the focus may bust the help system since
     // it relies on getting the current frame which conflicts with grabbing the focus.
commit 1db5a63365b6e35267d0a12ad0c0ab95b1256e75
Author: Thomas Arnhold <thomas at arnhold.org>
Date:   Sat Mar 29 18:54:45 2014 +0100

    typo: selektion -> selection

diff --git a/editeng/source/uno/unofored.cxx b/editeng/source/uno/unofored.cxx
index 88fce45..d395baa 100644
--- a/editeng/source/uno/unofored.cxx
+++ b/editeng/source/uno/unofored.cxx
@@ -190,7 +190,7 @@ sal_uInt16 GetSvxEditEngineItemState( EditEngine& rEditEngine, const ESelection&
         // get list of char attribs
         rEditEngine.GetCharAttribs( nPara, aAttribs );
 
-        sal_Bool bEmpty = sal_True;     // we found no item inside the selektion of this paragraph
+        sal_Bool bEmpty = sal_True;     // we found no item inside the selection of this paragraph
         sal_Bool bGaps  = sal_False;    // we found items but theire gaps between them
         sal_Int32 nLastEnd = nPos;
 
@@ -203,11 +203,11 @@ sal_uInt16 GetSvxEditEngineItemState( EditEngine& rEditEngine, const ESelection&
             const sal_Bool bEmptyPortion = i->nStart == i->nEnd;
             if((!bEmptyPortion && i->nStart >= nEndPos) ||
                (bEmptyPortion && i->nStart > nEndPos))
-                break;  // break if we are already behind our selektion
+                break;  // break if we are already behind our selection
 
             if((!bEmptyPortion && i->nEnd <= nPos) ||
                (bEmptyPortion && i->nEnd < nPos))
-                continue;   // or if the attribute ends before our selektion
+                continue;   // or if the attribute ends before our selection
 
             if(i->pAttr->Which() != nWhich)
                 continue; // skip if is not the searched item
diff --git a/starmath/source/accessibility.cxx b/starmath/source/accessibility.cxx
index 446941c..4288e4e 100644
--- a/starmath/source/accessibility.cxx
+++ b/starmath/source/accessibility.cxx
@@ -1146,7 +1146,7 @@ static sal_uInt16 GetSvxEditEngineItemState( EditEngine& rEditEngine, const ESel
         // get list of char attribs
         rEditEngine.GetCharAttribs( nPara, aAttribs );
 
-        bool bEmpty = true;     // we found no item inside the selektion of this paragraph
+        bool bEmpty = true;     // we found no item inside the selection of this paragraph
         bool bGaps  = false;    // we found items but theire gaps between them
         sal_Int32 nLastEnd = nPos;
 
@@ -1158,10 +1158,10 @@ static sal_uInt16 GetSvxEditEngineItemState( EditEngine& rEditEngine, const ESel
 
             const sal_Bool bEmptyPortion = (i->nStart == i->nEnd);
             if( (!bEmptyPortion && (i->nStart >= nEndPos)) || (bEmptyPortion && (i->nStart > nEndPos)) )
-                break;  // break if we are already behind our selektion
+                break;  // break if we are already behind our selection
 
             if( (!bEmptyPortion && (i->nEnd <= nPos)) || (bEmptyPortion && (i->nEnd < nPos)) )
-                continue;   // or if the attribute ends before our selektion
+                continue;   // or if the attribute ends before our selection
 
             if( i->pAttr->Which() != nWhich )
                 continue; // skip if is not the searched item
diff --git a/svx/source/table/tablecontroller.cxx b/svx/source/table/tablecontroller.cxx
index 42b9c46..7fef316 100644
--- a/svx/source/table/tablecontroller.cxx
+++ b/svx/source/table/tablecontroller.cxx
@@ -271,7 +271,7 @@ bool SvxTableController::onMouseButtonDown(const MouseEvent& rMEvt, Window* pWin
     if( rMEvt.IsRight() && eHit != SDRTABLEHIT_NONE )
         return true; // right click will become context menu
 
-    // for cell selektion with the mouse remember our first hit
+    // for cell selection with the mouse remember our first hit
     if( mbLeftButtonDown )
     {
         RemoveSelection();
diff --git a/sw/source/core/uibase/wrtsh/wrtsh1.cxx b/sw/source/core/uibase/wrtsh/wrtsh1.cxx
index 5d16ec8..e34a91d 100644
--- a/sw/source/core/uibase/wrtsh/wrtsh1.cxx
+++ b/sw/source/core/uibase/wrtsh/wrtsh1.cxx
@@ -451,7 +451,7 @@ sal_Bool SwWrtShell::InsertOleObject( const svt::EmbeddedObjectRef& xRef, SwFlyF
     //2. If the cursor is at the end of an non empty paragraph a paragraph
     //   break should be insertet. StarMath objects are character bound and
     //   no break should be inserted.
-    //3. If an selektion is passed to a StarMath object, this object should
+    //3. If an selection is passed to a StarMath object, this object should
     //   not be activated. sal_False should be returned then.
     bool bStarMath = true;
     sal_Bool bActivate = sal_True;
commit 5e04ec1e7d5adc9f14ea803d765aa42f8b0e08cd
Author: Thomas Arnhold <thomas at arnhold.org>
Date:   Sat Mar 29 18:53:49 2014 +0100

    typo: inteface -> interface

diff --git a/dtrans/source/win32/clipb/MtaOleClipb.cxx b/dtrans/source/win32/clipb/MtaOleClipb.cxx
index 82d97c4..1747eec 100644
--- a/dtrans/source/win32/clipb/MtaOleClipb.cxx
+++ b/dtrans/source/win32/clipb/MtaOleClipb.cxx
@@ -174,7 +174,7 @@ HRESULT MarshalIDataObjectInStream( IDataObject* pIDataObject, LPSTREAM* ppStrea
 
     *ppStream = NULL;
     return CoMarshalInterThreadInterfaceInStream(
-        __uuidof(IDataObject),  //The IID of inteface to be marshaled
+        __uuidof(IDataObject),  //The IID of interface to be marshaled
         pIDataObject,           //The interface pointer
         ppStream                //IStream pointer
         );
diff --git a/sal/workben/clipboardwben/testpaste/cbptest.cxx b/sal/workben/clipboardwben/testpaste/cbptest.cxx
index 283790f..f416987 100644
--- a/sal/workben/clipboardwben/testpaste/cbptest.cxx
+++ b/sal/workben/clipboardwben/testpaste/cbptest.cxx
@@ -363,7 +363,7 @@ void PasteClipboardData(HWND hwndParent)
     if ( SUCCEEDED( hr ) )
     {
         HRESULT hr = CoMarshalInterThreadInterfaceInStream(
-            __uuidof(IDataObject), //The IID of inteface to be marshaled
+            __uuidof(IDataObject), //The IID of interface to be marshaled
             pIDataObj,       //The interface pointer
             &g_pStm          //IStream pointer
             );
diff --git a/starmath/source/accessibility.cxx b/starmath/source/accessibility.cxx
index 284dd2d..446941c 100644
--- a/starmath/source/accessibility.cxx
+++ b/starmath/source/accessibility.cxx
@@ -858,7 +858,7 @@ SvxEditViewForwarder* SmEditSource::GetEditViewForwarder( bool /*bCreate*/ )
 
 void SmEditSource::UpdateData()
 {
-    // would possibly only by needed if the XText inteface is implemented
+    // would possibly only by needed if the XText interface is implemented
     // and its text needs to be updated.
 }
 
diff --git a/testtools/source/bridgetest/idl/bridgetest.idl b/testtools/source/bridgetest/idl/bridgetest.idl
index c7abd54..a11ba28 100644
--- a/testtools/source/bridgetest/idl/bridgetest.idl
+++ b/testtools/source/bridgetest/idl/bridgetest.idl
@@ -131,7 +131,7 @@ struct ThreeByteStruct
     byte                       c;
 };
 /**
- * complex types adding string, inteface, any
+ * complex types adding string, interface, any
  */
 struct TestElement : TestSimple
 {
diff --git a/udkapi/com/sun/star/reflection/XIdlClass.idl b/udkapi/com/sun/star/reflection/XIdlClass.idl
index 95a4faf..4509411 100644
--- a/udkapi/com/sun/star/reflection/XIdlClass.idl
+++ b/udkapi/com/sun/star/reflection/XIdlClass.idl
@@ -172,7 +172,7 @@ published interface XIdlClass: com::sun::star::uno::XInterface
         If the reflected type is not an array, then a null-reference is returned.
 
         @return
-                inteface to modify array instances (or null-reference)
+                interface to modify array instances (or null-reference)
     */
     XIdlArray getArray();
 
diff --git a/winaccessibility/source/UAccCOMIDL/ia2_api_all.idl b/winaccessibility/source/UAccCOMIDL/ia2_api_all.idl
index 04a2e7b..f014120 100644
--- a/winaccessibility/source/UAccCOMIDL/ia2_api_all.idl
+++ b/winaccessibility/source/UAccCOMIDL/ia2_api_all.idl
@@ -3686,7 +3686,7 @@ interface IAccessibleHypertext : IAccessibleText
 /** @brief This interface exposes information about hypertext in a document.
 
  The %IAccessibleHypertext2 interface extends the functinality of the
- %IAccessibleHypertext inteface.
+ %IAccessibleHypertext interface.
 */
 [object, uuid(CF64D89F-8287-4B44-8501-A827453A6077)]
 interface IAccessibleHypertext2 : IAccessibleHypertext
@@ -4326,7 +4326,7 @@ interface IAccessibleTable : IUnknown
  Please also refer to the IAccessibleTableCell interface.
 
  If you want to support older applications you should also support the
-  IAccessibleTable inteface.
+  IAccessibleTable interface.
 */
 [object, uuid(6167f295-06f0-4cdd-a1fa-02e25153d869)]
 interface IAccessibleTable2 : IUnknown
commit 920931529e2b7b11777328e91e2dcf3b7b746c1d
Author: Thomas Arnhold <thomas at arnhold.org>
Date:   Sat Mar 29 18:50:04 2014 +0100

    typo: visualy -> visually

diff --git a/starmath/inc/toolbox.hxx b/starmath/inc/toolbox.hxx
index e3d5e62..5dc062a 100644
--- a/starmath/inc/toolbox.hxx
+++ b/starmath/inc/toolbox.hxx
@@ -33,7 +33,7 @@ class SmToolBoxWindow : public SfxFloatingWindow
 
 protected:
     ToolBox     aToolBoxCat;
-    FixedLine   aToolBoxCat_Delim;  // to visualy separate the catalog part
+    FixedLine   aToolBoxCat_Delim;  // to visually separate the catalog part
     ToolBox    *pToolBoxCmd;
     ToolBox    *vToolBoxCategories[NUM_TBX_CATEGORIES];
     ImageList  *aImageLists [NUM_TBX_CATEGORIES + 1];   /* regular */
commit 32b16865b0bb0757885e27246901f262eb5e7eab
Author: Thomas Arnhold <thomas at arnhold.org>
Date:   Sat Mar 29 18:49:15 2014 +0100

    typo: horizontical -> horizontal

diff --git a/starmath/inc/cursor.hxx b/starmath/inc/cursor.hxx
index c5e3b85..0f4ca80 100644
--- a/starmath/inc/cursor.hxx
+++ b/starmath/inc/cursor.hxx
@@ -12,7 +12,7 @@
 #include "node.hxx"
 #include "caret.hxx"
 
-/** Factor to multiple the squared horizontical distance with
+/** Factor to multiple the squared horizontal distance with
  * Used for Up and Down movement.
  */
 #define HORIZONTICAL_DISTANCE_FACTOR        10
diff --git a/starmath/inc/node.hxx b/starmath/inc/node.hxx
index 8958897..0834a6c 100644
--- a/starmath/inc/node.hxx
+++ b/starmath/inc/node.hxx
@@ -771,7 +771,7 @@ public:
 
 
 
-/** Unary horizontical node
+/** Unary horizontal node
  *
  * The same as SmBinHorNode except this is for unary operators.
  */
@@ -897,7 +897,7 @@ public:
 
 
 
-/** Binary horizontical node
+/** Binary horizontal node
  *
  * This node is used for creating the OVER command, consider the formula:
  * "numerator OVER denominator", which looks like
commit d2dbab23caf580cc1ca0b5c5f0041da377cde593
Author: Thomas Arnhold <thomas at arnhold.org>
Date:   Sat Mar 29 18:46:14 2014 +0100

    typo: horizontial -> horizontal

diff --git a/starmath/inc/node.hxx b/starmath/inc/node.hxx
index a10aa92..8958897 100644
--- a/starmath/inc/node.hxx
+++ b/starmath/inc/node.hxx
@@ -863,7 +863,7 @@ public:
 
 
 
-/** Binary horizontial node
+/** Binary horizontal node
  *
  * This node is used for binary operators. In a formula such as "A + B".
  *
diff --git a/starmath/source/cursor.cxx b/starmath/source/cursor.cxx
index 5b98476..a869b4a 100644
--- a/starmath/source/cursor.cxx
+++ b/starmath/source/cursor.cxx
@@ -49,7 +49,7 @@ void SmCursor::Move(OutputDevice* pDev, SmMovementDirection direction, bool bMov
                         && direction == MoveUp) continue;
                 //Compare if it to what we have, if we have anything yet
                 if(NewPos){
-                    //Compute distance to current line squared, multiplied with a horizontial factor
+                    //Compute distance to current line squared, multiplied with a horizontal factor
                     long dp_sq = curr_line.SquaredDistanceX(from_line) * HORIZONTICAL_DISTANCE_FACTOR +
                                  curr_line.SquaredDistanceY(from_line);
                     //Discard current line if best line is closer
commit 993a863f45fa63d78cfa1cf46df31c85bf541463
Author: Thomas Arnhold <thomas at arnhold.org>
Date:   Sat Mar 29 18:44:37 2014 +0100

    typo: mayby -> maybe

diff --git a/starmath/inc/document.hxx b/starmath/inc/document.hxx
index b5d9e2b..7dbab07 100644
--- a/starmath/inc/document.hxx
+++ b/starmath/inc/document.hxx
@@ -54,7 +54,7 @@ class SmCursor;
  *
  * The printer can belong to the document or the OLE-Container. If the document
  * is an OLE-Document the printer generally belongs to the container too.
- * But the container mayby works with a different MapUnit than the server.
+ * But the container maybe works with a different MapUnit than the server.
  * Referring to the MapMode the printer will be accordingly adjusted in the
  * constructor and restored in the destructor. This brings that this class
  * is always allowed to exists only a short time (e.g. while painting).
commit 461ecf5cf4be2be9a752cb42aa0c0ad9549f1149
Author: Thomas Arnhold <thomas at arnhold.org>
Date:   Sat Mar 29 18:43:47 2014 +0100

    typo: constitues -> constitutes

diff --git a/starmath/inc/cursor.hxx b/starmath/inc/cursor.hxx
index 5e9d995..c5e3b85 100644
--- a/starmath/inc/cursor.hxx
+++ b/starmath/inc/cursor.hxx
@@ -394,11 +394,11 @@ private:
 
 /** Minimalistic recursive decent SmNodeList parser
  *
- * This parser is used to take a list of nodes that constitues a line
+ * This parser is used to take a list of nodes that constitutes a line
  * and parse them to a tree of SmBinHorNode, SmUnHorNode and SmExpression.
  *
  * Please note, this will not handle all kinds of nodes, only nodes that
- * constitues and entry in a line.
+ * constitutes and entry in a line.
  *
  * Below is an EBNF representation of the grammar used for this parser:
  * \code
diff --git a/starmath/inc/visitors.hxx b/starmath/inc/visitors.hxx
index f06b6b3..9a1ebb1 100644
--- a/starmath/inc/visitors.hxx
+++ b/starmath/inc/visitors.hxx
@@ -305,7 +305,7 @@ private:
 /** A visitor for building a SmCaretPosGraph
  *
  * Visit invariant:
- * Each pNode, except SmExpressionNode, SmBinHorNode and a few others, constitues an entry
+ * Each pNode, except SmExpressionNode, SmBinHorNode and a few others, constitutes an entry
  * in a line. Consider the line entry "H", this entry creates one carat position, here
  * denoted by | in "H|".
  *
@@ -482,7 +482,7 @@ public:
     void Visit( SmRectangleNode* pNode ) SAL_OVERRIDE;
     void Visit( SmVerticalBraceNode* pNode ) SAL_OVERRIDE;
 private:
-    /** Extract text from a pNode that constitues a line */
+    /** Extract text from a pNode that constitutes a line */
     void LineToText( SmNode* pNode ) {
         Separate( );
         if( pNode )
commit 56f81a619951d080e8047267a1e78112c6e38a28
Author: Thomas Arnhold <thomas at arnhold.org>
Date:   Sat Mar 29 18:42:06 2014 +0100

    typo: formatet -> formated

diff --git a/starmath/inc/cursor.hxx b/starmath/inc/cursor.hxx
index ca3527d..5e9d995 100644
--- a/starmath/inc/cursor.hxx
+++ b/starmath/inc/cursor.hxx
@@ -142,7 +142,7 @@ public:
     /** Insert a special node created from aString
      *
      * Used for handling insert request from the "catalog" dialog.
-     * The provided string should be formatet as the desired command: %phi
+     * The provided string should be formated as the desired command: %phi
      * Note: this method ONLY supports commands defined in Math.xcu
      *
      * For more complex expressions use InsertCommandText, this method doesn't
commit 25a06a317b1816c8cf7fe36e44186b7b93fedd86
Author: Thomas Arnhold <thomas at arnhold.org>
Date:   Sat Mar 29 18:41:06 2014 +0100

    typo: unpleasent -> unpleasant

diff --git a/starmath/inc/caret.hxx b/starmath/inc/caret.hxx
index e3f7b65..411781f 100644
--- a/starmath/inc/caret.hxx
+++ b/starmath/inc/caret.hxx
@@ -28,7 +28,7 @@ struct SmCaretPos{
      * Notice how there's special cases for SmTextNode.
      */
     //TODO: Special cases for SmBlankNode is needed
-    //TODO: Consider forgetting about the todo above... As it's really unpleasent.
+    //TODO: Consider forgetting about the todo above... As it's really unpleasant.
     int Index;
     /** True, if this is a valid caret position */
     bool IsValid() const { return pSelectedNode != NULL; }
commit f8d601cb539a14ac9a669410a0e2b4b96cb6f813
Author: Thomas Arnhold <thomas at arnhold.org>
Date:   Sat Mar 29 18:40:15 2014 +0100

    typo: equantion -> equation

diff --git a/starmath/inc/caret.hxx b/starmath/inc/caret.hxx
index 6eb6ecb..e3f7b65 100644
--- a/starmath/inc/caret.hxx
+++ b/starmath/inc/caret.hxx
@@ -11,7 +11,7 @@
 
 #include "node.hxx"
 
-/** Representation of caret position with an equantion */
+/** Representation of caret position with an equation */
 struct SmCaretPos{
     SmCaretPos(SmNode* selectedNode = NULL, int iIndex = 0) {
         pSelectedNode = selectedNode;
commit c289013572024bb04ff37e8ae0e5e8901c4339ca
Author: Thomas Arnhold <thomas at arnhold.org>
Date:   Sat Mar 29 18:30:25 2014 +0100

    typo: tempoary -> temporary

diff --git a/comphelper/source/misc/proxyaggregation.cxx b/comphelper/source/misc/proxyaggregation.cxx
index c2b89e9..ccd612d 100644
--- a/comphelper/source/misc/proxyaggregation.cxx
+++ b/comphelper/source/misc/proxyaggregation.cxx
@@ -50,7 +50,7 @@ namespace comphelper
         Reference< XProxyFactory > xFactory = ProxyFactory::create( m_xContext );
 
         // then the proxy itself
-        { // i36686 OJ: achieve the desctruction of the tempoary -> otherwise it leads to _rRefCount -= 2
+        { // i36686 OJ: achieve the desctruction of the temporary -> otherwise it leads to _rRefCount -= 2
             m_xProxyAggregate = xFactory->createProxy( _rxComponent );
         }
         if ( m_xProxyAggregate.is() )
commit 59f1e95844b420c529cd0205bba11cf3d0b73258
Author: Thomas Arnhold <thomas at arnhold.org>
Date:   Sat Mar 29 18:29:29 2014 +0100

    typo: previos -> previous

diff --git a/comphelper/source/misc/officeresourcebundle.cxx b/comphelper/source/misc/officeresourcebundle.cxx
index 054fe177..3fe6b8d 100644
--- a/comphelper/source/misc/officeresourcebundle.cxx
+++ b/comphelper/source/misc/officeresourcebundle.cxx
@@ -84,7 +84,7 @@ namespace comphelper
     private:
         /** loads the bundle represented by the instance
 
-            The method is safe against multiple calls: If a previos call succeeded or failed, the
+            The method is safe against multiple calls: If a previous call succeeded or failed, the
             previous result will be returned, without any other processing.
 
             @precond
commit dc8f33ba5d0324b6a3d34c37f0a6f66a1ad3d12b
Author: Thomas Arnhold <thomas at arnhold.org>
Date:   Sat Mar 29 18:28:02 2014 +0100

    typo: decription -> description

diff --git a/comphelper/source/misc/evtmethodhelper.cxx b/comphelper/source/misc/evtmethodhelper.cxx
index d69bdfd..1c805f2 100644
--- a/comphelper/source/misc/evtmethodhelper.cxx
+++ b/comphelper/source/misc/evtmethodhelper.cxx
@@ -38,7 +38,7 @@ namespace comphelper
         OUString* pNames = aNames.getArray();
         for(sal_Int32 i=0;i<pType->nMembers;i++,++pNames)
         {
-            // the decription reference
+            // the description reference
             typelib_TypeDescriptionReference* pMemberDescriptionReference = pType->ppMembers[i];
             // the description for the reference
             typelib_TypeDescription* pMemberDescription = NULL;
@@ -56,10 +56,4 @@ namespace comphelper
 
 }
 
-
-
-
-
-
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/udkapi/com/sun/star/uno/XReference.idl b/udkapi/com/sun/star/uno/XReference.idl
index f1d1f86..39b4cdb 100644
--- a/udkapi/com/sun/star/uno/XReference.idl
+++ b/udkapi/com/sun/star/uno/XReference.idl
@@ -26,7 +26,7 @@
  module com {  module sun {  module star {  module uno {
 
 /** must be implemented by anyone who holds the adapter on the client side. at see XWeak
-        for decription af concepts.
+        for description af concepts.
  */
 published interface XReference: com::sun::star::uno::XInterface
 {
commit b4b180db13d9525277164732d7ad7c77d404e29d
Author: Thomas Arnhold <thomas at arnhold.org>
Date:   Sat Mar 29 18:25:27 2014 +0100

    typo: temorary -> temporary

diff --git a/comphelper/source/container/embeddedobjectcontainer.cxx b/comphelper/source/container/embeddedobjectcontainer.cxx
index b10be39..707cfc04 100644
--- a/comphelper/source/container/embeddedobjectcontainer.cxx
+++ b/comphelper/source/container/embeddedobjectcontainer.cxx
@@ -451,7 +451,7 @@ void EmbeddedObjectContainer::AddEmbeddedObject( const ::com::sun::star::uno::Re
     if ( xChild.is() && xChild->getParent() != pImpl->m_xModel.get() )
         xChild->setParent( pImpl->m_xModel.get() );
 
-    // look for object in temorary container
+    // look for object in temporary container
     if ( pImpl->mpTempObjectContainer )
     {
         aIt = pImpl->mpTempObjectContainer->pImpl->maObjectContainer.begin();
diff --git a/svx/source/sdr/contact/viewcontactofe3dscene.cxx b/svx/source/sdr/contact/viewcontactofe3dscene.cxx
index e82bcdc..e37b3a3 100644
--- a/svx/source/sdr/contact/viewcontactofe3dscene.cxx
+++ b/svx/source/sdr/contact/viewcontactofe3dscene.cxx
@@ -198,7 +198,7 @@ namespace sdr
                 const double fMinZ(-aCameraRange.getMaxZ());
                 const double fMaxZ(-aCameraRange.getMinZ());
 
-                // construct temorary matrix from world to device. Use unit values here to measure expansion
+                // construct temporary matrix from world to device. Use unit values here to measure expansion
                 basegfx::B3DHomMatrix aWorldToDevice(aWorldToCamera);
                 const drawinglayer::attribute::SdrSceneAttribute& rSdrSceneAttribute = getSdrSceneAttribute();
 
commit 67587cdf8c893ff717ece6517d5520be75bd4a30
Author: Thomas Arnhold <thomas at arnhold.org>
Date:   Sat Mar 29 18:24:30 2014 +0100

    typo: Exceptiopn -> Exception

diff --git a/comphelper/source/container/containermultiplexer.cxx b/comphelper/source/container/containermultiplexer.cxx
index 4f04c5b..adc6e13 100644
--- a/comphelper/source/container/containermultiplexer.cxx
+++ b/comphelper/source/container/containermultiplexer.cxx
@@ -111,7 +111,7 @@ namespace comphelper
         }
         catch(const Exception&)
         {
-            OSL_FAIL("Exceptiopn caught!");
+            OSL_FAIL("Exception caught!");
         }
         ::comphelper::decrement(m_refCount);
     }
commit 02c83db00a31707c81e78cd5c5a45e3e34da39ca
Author: Thomas Arnhold <thomas at arnhold.org>
Date:   Sat Mar 29 18:22:04 2014 +0100

    typo: enoungh -> enough

diff --git a/comphelper/source/streaming/seqstream.cxx b/comphelper/source/streaming/seqstream.cxx
index 2e1552a..5bc44a5 100644
--- a/comphelper/source/streaming/seqstream.cxx
+++ b/comphelper/source/streaming/seqstream.cxx
@@ -163,7 +163,7 @@ void SAL_CALL OSequenceOutputStream::writeBytes( const Sequence< sal_Int8 >& _rD
     if (!m_bConnected)
         throw NotConnectedException();
 
-    // ensure the sequence has enoungh space left
+    // ensure the sequence has enough space left
     if (m_nSize + _rData.getLength() > m_rSequence.getLength())
     {
         sal_Int32 nCurrentLength = m_rSequence.getLength();
commit cc3a302fcb564b996740524a6c5e6934d9ce8824
Author: Thomas Arnhold <thomas at arnhold.org>
Date:   Sat Mar 29 18:19:31 2014 +0100

    typo: unfortunally -> unfortunately

diff --git a/comphelper/source/property/propertycontainerhelper.cxx b/comphelper/source/property/propertycontainerhelper.cxx
index 13f3307..23b0583 100644
--- a/comphelper/source/property/propertycontainerhelper.cxx
+++ b/comphelper/source/property/propertycontainerhelper.cxx
@@ -489,7 +489,7 @@ void OPropertyContainerHelper::describeProperties(Sequence< Property >& _rProps)
     // as our property vector is sorted by handles, not by name, we have to sort aOwnProps
     ::std::sort(aOwnProps.getArray(), aOwnProps.getArray() + aOwnProps.getLength(), PropertyCompareByName());
 
-    // unfortunally the STL merge function does not allow the output range to overlap one of the input ranges,
+    // unfortunately the STL merge function does not allow the output range to overlap one of the input ranges,
     // so we need an extra sequence
     Sequence< Property > aOutput;
     aOutput.realloc(_rProps.getLength() + aOwnProps.getLength());
diff --git a/forms/source/component/ImageControl.cxx b/forms/source/component/ImageControl.cxx
index 1410ff4..26979a5 100644
--- a/forms/source/component/ImageControl.cxx
+++ b/forms/source/component/ImageControl.cxx
@@ -627,7 +627,7 @@ void OImageControlModel::doSetControlValue( const Any& _rValue )
         Reference< XImageProducer > xProducer = m_xImageProducer;
         {
             // release our mutex once (it's acquired in the calling method!), as starting the image production may
-            // result in the locking of the solar mutex (unfortunally the default implementation of our aggregate,
+            // result in the locking of the solar mutex (unfortunately the default implementation of our aggregate,
             // VCLXImageControl, does this locking)
             MutexRelease aRelease(m_aMutex);
             xProducer->startProduction();
diff --git a/forms/source/inc/FormComponent.hxx b/forms/source/inc/FormComponent.hxx
index 04e28e9..1c78873 100644
--- a/forms/source/inc/FormComponent.hxx
+++ b/forms/source/inc/FormComponent.hxx
@@ -973,7 +973,7 @@ protected:
                             getCurrentFormComponentValue() const;
 
     /** We can't write (new) common properties in this base class, as the file format doesn't allow this
-        (unfortunally). So derived classes may use the following two methods. They secure the written
+        (unfortunately). So derived classes may use the following two methods. They secure the written
         data with marks, so any new common properties in newer versions will be skipped by older ones.
     */
     void    writeCommonProperties(const ::com::sun::star::uno::Reference< ::com::sun::star::io::XObjectOutputStream>& _rxOutStream);
diff --git a/include/comphelper/types.hxx b/include/comphelper/types.hxx
index 5822316..b91b24c 100644
--- a/include/comphelper/types.hxx
+++ b/include/comphelper/types.hxx
@@ -70,7 +70,7 @@ namespace comphelper
     /** just a small shortcut ...
         check if a type you have at hand at runtime is equal to another type you have at compile time
         if all our compiler would accept function calls with explicit template arguments (like
-        isA<classFoo>(runtimeType)), we wouldn't need the second parameter. But unfortunally at
+        isA<classFoo>(runtimeType)), we wouldn't need the second parameter. But unfortunately at
         least the current solaris compiler doesn't allow this ....
         So this function is nearly senseless ....
     */
commit e5355180f4f42d3ad0d630c2a9bf7a0a63a1aa06
Author: Thomas Arnhold <thomas at arnhold.org>
Date:   Sat Mar 29 18:17:14 2014 +0100

    typo: sicne -> since

diff --git a/comphelper/source/container/enumerablemap.cxx b/comphelper/source/container/enumerablemap.cxx
index 247c18d..2eb27c7 100644
--- a/comphelper/source/container/enumerablemap.cxx
+++ b/comphelper/source/container/enumerablemap.cxx
@@ -333,7 +333,7 @@ namespace comphelper
         }
 
     private:
-        // sicne we share our mutex with the main map, we need to keep it alive as long as we live
+        // since we share our mutex with the main map, we need to keep it alive as long as we live
         Reference< XInterface >     m_xKeepMapAlive;
         ::std::auto_ptr< MapData >  m_pMapDataCopy;
         MapEnumerator               m_aEnumerator;
commit 45d38ff6c4e7026beb01463da52708a8824cdec0
Author: Thomas Arnhold <thomas at arnhold.org>
Date:   Sat Mar 29 18:16:18 2014 +0100

    typo: tranfer -> transfer

diff --git a/comphelper/source/container/embeddedobjectcontainer.cxx b/comphelper/source/container/embeddedobjectcontainer.cxx
index 8c93fad..b10be39 100644
--- a/comphelper/source/container/embeddedobjectcontainer.cxx
+++ b/comphelper/source/container/embeddedobjectcontainer.cxx
@@ -766,7 +766,7 @@ uno::Reference < embed::XEmbeddedObject > EmbeddedObjectContainer::CopyAndGetEmb
                     // this must be an object based on properties, otherwise we can not copy it currently
                     uno::Reference< beans::XPropertySet > xOrigProps( xObj->getComponent(), uno::UNO_QUERY_THROW );
 
-                    // use object class ID to create a new one and tranfer all the properties
+                    // use object class ID to create a new one and transfer all the properties
                     uno::Reference < embed::XEmbeddedObjectCreator > xCreator =
                         embed::EmbeddedObjectCreator::create( ::comphelper::getProcessComponentContext() );
 
diff --git a/ucb/source/ucp/file/filglob.cxx b/ucb/source/ucp/file/filglob.cxx
index 143724b..bc19533 100644
--- a/ucb/source/ucp/file/filglob.cxx
+++ b/ucb/source/ucp/file/filglob.cxx
@@ -791,7 +791,7 @@ namespace fileaccess {
         {
             aAny <<=
                 InteractiveBadTransferURLException(
-                    OUString( "bad tranfer url"),
+                    OUString( "bad transfer url"),
                     xComProc);
             cancelCommandExecution( aAny,xEnv );
         }
commit ee1de9427614a99cdbfe3a122db74e30f93d07d2
Author: Thomas Arnhold <thomas at arnhold.org>
Date:   Sat Mar 29 18:15:35 2014 +0100

    typo: persistance -> persistence

diff --git a/embeddedobj/source/inc/commonembobj.hxx b/embeddedobj/source/inc/commonembobj.hxx
index 77bba8a..542a160 100644
--- a/embeddedobj/source/inc/commonembobj.hxx
+++ b/embeddedobj/source/inc/commonembobj.hxx
@@ -231,7 +231,7 @@ public:
         const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext >& rxContext,
         const ::com::sun::star::uno::Sequence< ::com::sun::star::beans::NamedValue >& aObjectProps );
 
-    // no persistance for linked objects, so the descriptors are provided in constructor
+    // no persistence for linked objects, so the descriptors are provided in constructor
     OCommonEmbeddedObject(
         const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext >& rxContext,
         const ::com::sun::star::uno::Sequence< ::com::sun::star::beans::NamedValue >& aObjectProps,
diff --git a/embeddedobj/test/Container1/EmbedContApp.java b/embeddedobj/test/Container1/EmbedContApp.java
index 4481a98..f9bbd95 100644
--- a/embeddedobj/test/Container1/EmbedContApp.java
+++ b/embeddedobj/test/Container1/EmbedContApp.java
@@ -560,7 +560,7 @@ public class EmbedContApp extends Applet
                 {
                     if ( m_xStorage != null && m_xEmbedObj != null )
                     {
-                        // if has persistance store there
+                        // if has persistence store there
                         // if not it is and error, SaveAs had to be used
 
                         if ( m_bOwnFile )
@@ -1042,7 +1042,7 @@ public class EmbedContApp extends Applet
 
         public void actionPerformed( ActionEvent e )
         {
-            // if has persistance store there
+            // if has persistence store there
             // if not open SaveAs dialog and store
             if ( m_xStorage != null && m_xEmbedObj != null )
             {
diff --git a/odk/examples/java/EmbedDocument/Container1/EmbedContApp.java b/odk/examples/java/EmbedDocument/Container1/EmbedContApp.java
index a56a2ad..5c01baf 100644
--- a/odk/examples/java/EmbedDocument/Container1/EmbedContApp.java
+++ b/odk/examples/java/EmbedDocument/Container1/EmbedContApp.java
@@ -379,7 +379,7 @@ public class EmbedContApp extends Applet implements MouseListener, XEmbeddedClie
 
         public void actionPerformed( ActionEvent e )
         {
-            // if has persistance store there
+            // if has persistence store there
             // if not open SaveAs dialog and store
             if ( m_xStorage != null && m_xEmbedObj != null )
             {
diff --git a/sfx2/source/doc/objstor.cxx b/sfx2/source/doc/objstor.cxx
index 520d168..9aedbfd 100644
--- a/sfx2/source/doc/objstor.cxx
+++ b/sfx2/source/doc/objstor.cxx
@@ -1239,9 +1239,9 @@ bool SfxObjectShell::SaveTo_Impl
                 // The active storage must be switched. The simple saving is not enough.
                 // The problem is that the target medium contains target MediaDescriptor.
 
-                    // In future the switch of the persistance could be done on stream level:
+                    // In future the switch of the persistence could be done on stream level:
                     // a new wrapper service will be implemented that allows to exchange
-                    // persistance on the fly. So the real persistance will be set
+                    // persistence on the fly. So the real persistence will be set
                     // to that stream only after successful commit of the storage.
                     // TODO/LATER:
                     // create wrapper stream based on the URL
diff --git a/sfx2/source/view/ipclient.cxx b/sfx2/source/view/ipclient.cxx
index 38c9ad3..7fe0c98 100644
--- a/sfx2/source/view/ipclient.cxx
+++ b/sfx2/source/view/ipclient.cxx
@@ -224,7 +224,7 @@ void SAL_CALL SfxInPlaceClient_Impl::saveObject()
         // and the user didn't request saving the changes
         return;
 
-    // the common persistance is supported by objects and links
+    // the common persistence is supported by objects and links
     uno::Reference< embed::XCommonEmbedPersist > xPersist( m_xObject, uno::UNO_QUERY );
     if ( !xPersist.is() )
         throw uno::RuntimeException();
diff --git a/svtools/source/misc/embedtransfer.cxx b/svtools/source/misc/embedtransfer.cxx
index 36a00b3..a87191c 100644
--- a/svtools/source/misc/embedtransfer.cxx
+++ b/svtools/source/misc/embedtransfer.cxx
@@ -140,7 +140,7 @@ bool SvEmbedTransferHelper::GetData( const ::com::sun::star::datatransfer::DataF
                         }
                         else
                         {
-                            //TODO/LATER: how to handle objects without persistance?!
+                            //TODO/LATER: how to handle objects without persistence?!
                         }
                     }
                     catch ( uno::Exception& )
diff --git a/sw/source/core/ole/ndole.cxx b/sw/source/core/ole/ndole.cxx
index 636b6f8..789929a 100644
--- a/sw/source/core/ole/ndole.cxx
+++ b/sw/source/core/ole/ndole.cxx
@@ -873,7 +873,7 @@ sal_Bool SwOLEObj::UnloadObject( uno::Reference< embed::XEmbeddedObject > xObj,
                         if ( xPers.is() )
                             xPers->storeOwn();
                         else {
-                            OSL_FAIL("Modified object without persistance in cache!");
+                            OSL_FAIL("Modified object without persistence in cache!");
                         }
                     }
 
diff --git a/xmloff/source/draw/shapeexport.cxx b/xmloff/source/draw/shapeexport.cxx
index f2f7c1b..9bd4258 100644
--- a/xmloff/source/draw/shapeexport.cxx
+++ b/xmloff/source/draw/shapeexport.cxx
@@ -2751,7 +2751,7 @@ void XMLShapeExport::ImpExportOLE2Shape(
 
                 if ( bInternal )
                 {
-                    // OOo internal links have no storage persistance, URL is stored in the XML file
+                    // OOo internal links have no storage persistence, URL is stored in the XML file
                     // the result LinkURL is empty in case the object is not a link
                     xPropSet->getPropertyValue("LinkURL") >>= sURL;
                 }
diff --git a/xmloff/source/text/XMLTextFrameContext.cxx b/xmloff/source/text/XMLTextFrameContext.cxx
index 9387f3c..9c8d504 100644
--- a/xmloff/source/text/XMLTextFrameContext.cxx
+++ b/xmloff/source/text/XMLTextFrameContext.cxx
@@ -509,7 +509,7 @@ void XMLTextFrameContext_Impl::Create( sal_Bool /*bHRefOrBase64*/ )
                 }
                 else
                 {
-                    // it should be an own OOo link that has no storage persistance
+                    // it should be an own OOo link that has no storage persistence
                     xPropSet = GetImport().GetTextImport()
                             ->createAndInsertOOoLink( GetImport(),
                                                         sURL,
commit 7d3b9d3333aa1aaa1066863f95e29e506e21ad52
Author: Thomas Arnhold <thomas at arnhold.org>
Date:   Sat Mar 29 18:13:39 2014 +0100

    typo: optimisation -> optimization

diff --git a/basebmp/test/polytest.cxx b/basebmp/test/polytest.cxx
index 64f6933..a0371eb 100644
--- a/basebmp/test/polytest.cxx
+++ b/basebmp/test/polytest.cxx
@@ -220,7 +220,7 @@ private:
 
         // trigger "clipCode1 & aMinFlag/bMinFlag" cases in
         // clippedlinerenderer.hxx (note1: needs forcing end point to
-        // be clipped as well, otherwise optimisation kicks in. note2:
+        // be clipped as well, otherwise optimization kicks in. note2:
         // needs forcing end point to clip on two edges, not only on
         // one, otherwise swap kicks in)
         const basegfx::B2IPoint aPt5(1,1);
diff --git a/canvas/source/vcl/canvashelper_texturefill.cxx b/canvas/source/vcl/canvashelper_texturefill.cxx
index 8514f8a..a34d5df 100644
--- a/canvas/source/vcl/canvashelper_texturefill.cxx
+++ b/canvas/source/vcl/canvashelper_texturefill.cxx
@@ -578,7 +578,7 @@ namespace vclcanvas
 
 
                 // this distinction really looks like a
-                // micro-optimisation, but in fact greatly speeds up
+                // micro-optimization, but in fact greatly speeds up
                 // especially complex gradients. That's because when using
                 // clipping, we can output polygons instead of
                 // poly-polygons, and don't have to output the gradient
@@ -963,7 +963,7 @@ namespace vclcanvas
 
 
                         // this distinction really looks like a
-                        // micro-optimisation, but in fact greatly speeds up
+                        // micro-optimization, but in fact greatly speeds up
                         // especially complex fills. That's because when using
                         // clipping, we can output polygons instead of
                         // poly-polygons, and don't have to output the gradient
diff --git a/comphelper/source/container/embeddedobjectcontainer.cxx b/comphelper/source/container/embeddedobjectcontainer.cxx
index 9ccd567..546d51b 100644
--- a/comphelper/source/container/embeddedobjectcontainer.cxx
+++ b/comphelper/source/container/embeddedobjectcontainer.cxx
@@ -517,7 +517,7 @@ bool EmbeddedObjectContainer::StoreEmbeddedObject( const uno::Reference < embed:
                 xPersist->storeToEntry( pImpl->mxStorage, rName, aSeq, aSeq );
             else
             {
-                //TODO/LATER: possible optimisation, don't store immediately
+                //TODO/LATER: possible optimization, don't store immediately
                 //xPersist->setPersistentEntry( pImpl->mxStorage, rName, embed::EntryInitModes::ENTRY_NO_INIT, aSeq, aSeq );
                 xPersist->storeAsEntry( pImpl->mxStorage, rName, aSeq, aSeq );
                 xPersist->saveCompleted( sal_True );
diff --git a/include/o3tl/sorted_vector.hxx b/include/o3tl/sorted_vector.hxx
index 776fd56..3a7abe0 100644
--- a/include/o3tl/sorted_vector.hxx
+++ b/include/o3tl/sorted_vector.hxx
@@ -141,7 +141,7 @@ public:
 
     void insert(sorted_vector<Value,Compare,Find> const& rOther)
     {
-       // optimisation for the rather common case that we are overwriting this with the contents
+       // optimization for the rather common case that we are overwriting this with the contents
        // of another sorted vector
        if ( empty() )
        {
diff --git a/package/source/zippackage/ZipPackage.cxx b/package/source/zippackage/ZipPackage.cxx
index 032ee5d..7272f9a 100644
--- a/package/source/zippackage/ZipPackage.cxx
+++ b/package/source/zippackage/ZipPackage.cxx
@@ -629,7 +629,7 @@ void SAL_CALL ZipPackage::initialize( const uno::Sequence< Any >& aArguments )
                         m_xContext );
                     Any aAny = aContent.getPropertyValue("Size");
                     sal_uInt64 aSize = 0;
-                    // kind of optimisation: treat empty files as nonexistent files
+                    // kind of optimization: treat empty files as nonexistent files
                     // and write to such files directly. Note that "Size" property is optional.
                     bool bHasSizeProperty = aAny >>= aSize;
                     if( !bHasSizeProperty || ( bHasSizeProperty && aSize ) )
diff --git a/sd/source/ui/slideshow/slideshowviewimpl.cxx b/sd/source/ui/slideshow/slideshowviewimpl.cxx
index 903e1ee..853a30f 100644
--- a/sd/source/ui/slideshow/slideshowviewimpl.cxx
+++ b/sd/source/ui/slideshow/slideshowviewimpl.cxx
@@ -661,7 +661,7 @@ void SlideShowView::init()
 
     getTransformation();
 
-    // #i48939# only switch on kind of hacky scroll optimisation, when
+    // #i48939# only switch on kind of hacky scroll optimization, when
     // running fullscreen. this minimizes the probability that other
     // windows partially cover the show.
     if( mbFullScreen )
diff --git a/solenv/gbuild/platform/com_MSC_defs.mk b/solenv/gbuild/platform/com_MSC_defs.mk
index 67d2b6b..36c14e9 100644
--- a/solenv/gbuild/platform/com_MSC_defs.mk
+++ b/solenv/gbuild/platform/com_MSC_defs.mk
@@ -194,7 +194,7 @@ endif
 ifneq ($(ENABLE_LTO),)
 
 # Sigh, but there are cases of C4702 when using link-time code
-# generation and optimisation where I couldn't get
+# generation and optimization where I couldn't get
 # __pragma(warning(disable:4702)) to help. Especially, the
 # ImplInheritanceHelper2() {} in <cppuhelper/implbase2.hxx>
 # was reported as containing "unreachable code" when linking
diff --git a/sw/source/core/layout/wsfrm.cxx b/sw/source/core/layout/wsfrm.cxx
index 078175d..2ab3ca0 100644
--- a/sw/source/core/layout/wsfrm.cxx
+++ b/sw/source/core/layout/wsfrm.cxx
@@ -2922,7 +2922,7 @@ void SwLayoutFrm::ChgLowersProp( const Size& rOldSize )
     }
 
     // Finally adjust the columns if width is set to auto
-    // Possible optimisation: execute this code earlier in this function and
+    // Possible optimization: execute this code earlier in this function and
     // return???
     if ( ( (bVert && bHeightChgd) || (! bVert && bWidthChgd) ) &&
            Lower()->IsColumnFrm() )
diff --git a/sw/source/core/text/pormulti.cxx b/sw/source/core/text/pormulti.cxx
index bd87c74..d215d19 100644
--- a/sw/source/core/text/pormulti.cxx
+++ b/sw/source/core/text/pormulti.cxx
@@ -1970,7 +1970,7 @@ bool SwTxtFormatter::BuildMultiPortion( SwTxtFormatInfo &rInf,
         }
         else
         {
-            // For Solaris, this optimisation can causes trouble:
+            // For Solaris, this optimization can causes trouble:
             // Setting this to the portion width ( = rMulti.Width() )
             // can make GetTextBreak inside SwTxtGuess::Guess return to small
             // values. Therefore we add some extra twips.
diff --git a/vcl/source/gdi/outdev2.cxx b/vcl/source/gdi/outdev2.cxx
index 8ac1b35..6506095 100644
--- a/vcl/source/gdi/outdev2.cxx
+++ b/vcl/source/gdi/outdev2.cxx
@@ -1051,7 +1051,7 @@ void OutputDevice::DrawDeviceBitmap( const Point& rDestPt, const Size& rDestSize
                     // that should considerably increase performance for
                     // large bitmaps and small clippings.
 
-                    // Note that this optimisation is a workaround for a
+                    // Note that this optimization is a workaround for a
                     // Writer peculiarity, namely, to decompose background
                     // graphics into myriads of disjunct, tiny
                     // rectangles. That otherwise kills us here, since for
diff --git a/vcl/source/window/window.cxx b/vcl/source/window/window.cxx
index 6736c54..6ae5700 100644
--- a/vcl/source/window/window.cxx
+++ b/vcl/source/window/window.cxx
@@ -1467,7 +1467,7 @@ void Window::ImplLoadRes( const ResId& rResId )
 
     sal_uLong nRSStyle = aHeader.nRSStyle;
 
-    // looks bad due to optimisation
+    // looks bad due to optimization
     if ( nRSStyle & RSWND_CLIENTSIZE )
     {
         if ( bPos )
@@ -7127,7 +7127,7 @@ void Window::SetZOrder( Window* pRefWindow, sal_uInt16 nFlags )
 
             // When ClipRegion was not initialised, assume
             // the window has not been sent, therefore do not
-            // trigger any Invalidates. This is an optimisation
+            // trigger any Invalidates. This is an optimization
             // for HTML documents with many controls. If this
             // check gives problems, a flag should be introduced
             // which tracks whether the window has already been
commit 8bb09efc92fe4de373f4ed4759f29108feb8cc3a
Author: Thomas Arnhold <thomas at arnhold.org>
Date:   Sat Mar 29 18:09:41 2014 +0100

    typo: approriate -> appropriate

diff --git a/comphelper/source/container/container.cxx b/comphelper/source/container/container.cxx
index 73a3b20..dffc2a3 100644
--- a/comphelper/source/container/container.cxx
+++ b/comphelper/source/container/container.cxx
@@ -76,7 +76,7 @@ IndexAccessIterator::~IndexAccessIterator() {}
                 while (m_arrChildIndizies.size() > 0)
                 {   // If the list isn't empty and there's nothing above
                     ::com::sun::star::uno::Reference< ::com::sun::star::container::XChild> xChild(xSearchLoop, ::com::sun::star::uno::UNO_QUERY);
-                    OSL_ENSURE(xChild.is(), "IndexAccessIterator::Next : a content has no approriate interface !");
+                    OSL_ENSURE(xChild.is(), "IndexAccessIterator::Next : a content has no appropriate interface !");
 
                     ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface> xParent( xChild->getParent());
                     xContainerAccess = ::com::sun::star::uno::Reference< ::com::sun::star::container::XIndexAccess>(xParent, ::com::sun::star::uno::UNO_QUERY);
diff --git a/include/unotools/syslocaleoptions.hxx b/include/unotools/syslocaleoptions.hxx
index 8439d7f..9e1e164 100644
--- a/include/unotools/syslocaleoptions.hxx
+++ b/include/unotools/syslocaleoptions.hxx
@@ -119,7 +119,7 @@ public:
             void                SetDatePatternsConfigString( const OUString& rStr );
 
     // determine whether the decimal separator defined in the keyboard layout is used
-    // or the one approriate to the locale
+    // or the one appropriate to the locale
             bool                IsDecimalSeparatorAsLocale() const;
             void                SetDecimalSeparatorAsLocale( bool bSet);
 
diff --git a/sw/source/core/doc/doctxm.cxx b/sw/source/core/doc/doctxm.cxx
index 9b3cc25..c37bc37 100644
--- a/sw/source/core/doc/doctxm.cxx
+++ b/sw/source/core/doc/doctxm.cxx
@@ -773,7 +773,7 @@ void SwTOXBaseSection::Update(const SfxItemSet* pAttr,
         pDoc->ChgFmt(*GetFmt(), *pAttr);
 
     // determine default page description, which will be used by the content nodes,
-    // if no approriate one is found.
+    // if no appropriate one is found.
     const SwPageDesc* pDefaultPageDesc;
     {
         pDefaultPageDesc =


More information about the Libreoffice-commits mailing list
diff --git a/comphelper/source/container/embeddedobjectcontainer.cxx b/comphelper/source/container/embeddedobjectcontainer.cxx
index 546d51b..8c93fad 100644
--- a/comphelper/source/container/embeddedobjectcontainer.cxx
+++ b/comphelper/source/container/embeddedobjectcontainer.cxx
@@ -438,7 +438,7 @@ void EmbeddedObjectContainer::AddEmbeddedObject( const ::com::sun::star::uno::Re
     uno::Reference < container::XNameAccess > xAccess( pImpl->mxStorage, uno::UNO_QUERY );
     uno::Reference < embed::XEmbedPersist > xEmb( xObj, uno::UNO_QUERY );
     uno::Reference < embed::XLinkageSupport > xLink( xEmb, uno::UNO_QUERY );
-    // if the object has a persistance and the object is not a link than it must have persistence entry in the storage
+    // if the object has a persistence and the object is not a link than it must have persistence entry in the storage
     OSL_ENSURE( !( xEmb.is() && ( !xLink.is() || !xLink->isLink() ) ) || xAccess->hasByName(rName),
                     "Added element not in storage!" );
 #endif
@@ -721,7 +721,7 @@ uno::Reference < embed::XEmbeddedObject > EmbeddedObjectContainer::CopyAndGetEmb
     if ( rName.isEmpty() )
         rName = CreateUniqueObjectName();
 
     // objects without persistance are not really stored by the method
     if ( xObj.is() && StoreEmbeddedObject( xObj, rName, true ) )
     {
         xResult = Get_Impl( rName, xObj);
@@ -830,7 +830,7 @@ uno::Reference < embed::XEmbeddedObject > EmbeddedObjectContainer::CopyAndGetEmb
         }
     }
 
-    SAL_WARN_IF( !xResult.is(), "comphelper.container", "Can not copy embedded object that has no persistance!\n" );
+    SAL_WARN_IF( !xResult.is(), "comphelper.container", "Can not copy embedded object that has no persistence!\n" );
 
     if ( xResult.is() )
     {
@@ -999,7 +999,7 @@ bool EmbeddedObjectContainer::RemoveEmbeddedObject( const uno::Reference < embed
     uno::Reference < embed::XLinkageSupport > xLink( xPersist, uno::UNO_QUERY );
     sal_Bool bIsNotEmbedded = !xPersist.is() || ( xLink.is() && xLink->isLink() );
 
-    // if the object has a persistance and the object is not a link than it must have persistence entry in the storage
+    // if the object has a persistence and the object is not a link than it must have persistence entry in the storage
     OSL_ENSURE( bIsNotEmbedded || xAccess->hasByName(aName), "Removing element not present in storage!" );
 #endif
 
@@ -1113,7 +1113,7 @@ bool EmbeddedObjectContainer::RemoveEmbeddedObject( const uno::Reference < embed
         try
         {
 #if OSL_DEBUG_LEVEL > 1
-            // if the object has a persistance and the object is not a link than it must have persistence entry in storage
+            // if the object has a persistence and the object is not a link than it must have persistence entry in storage
             OSL_ENSURE( bIsNotEmbedded || pImpl->mxStorage->hasByName( aName ), "The object has no persistence entry in the storage!" );
 #endif
             if ( xPersist.is() && pImpl->mxStorage->hasByName( aName ) )
@@ -721,7 +721,7 @@ uno::Reference < embed::XEmbeddedObject > EmbeddedObjectContainer::CopyAndGetEmb
         rName = CreateUniqueObjectName();
 
-    // objects without persistance are not really stored by the method
+    // objects without persistence are not really stored by the method
     if ( xObj.is() && StoreEmbeddedObject( xObj, rName, true ) )
     {